@@ -16,14 +16,16 @@ def hub(**kw):
     """ Run the fedmsg hub. """
 
     # Check if the user wants the websocket server to run
-    if 'moksha.livesocket.websocket.port' in kw:
+    if kw['moksha.livesocket.websocket.port']:
         kw['moksha.livesocket.backend'] = 'websocket'
 
     # Rephrase the fedmsg-config.py config as moksha *.ini format.
     # Note that the hub we kick off here cannot send any message.  You should
     # use fedmsg.send_message(...) still for that.
     moksha_options = dict(
-        zmq_subscribe_endpoints=','.join(kw['endpoints'].values()),
+        zmq_subscribe_endpoints=','.join(
+            ','.join(bunch) for bunch in kw['endpoints'].values()
+        ),
     )
     kw.update(moksha_options)
 
